@@ -53,8 +53,8 @@ WRONG_LENGTH = _("Per favore usa una lunghezza massima del nome dell'allegato "
                  "inferiore a {}. Attualmente hai inserito un nome di {} caratteri")
 
 # formset special words
-FORMSET_REGEX = "^(?P<field_name>{})-(?P<index>[0-9]+)-(?P<name>[a-zA-ZÀ-ÿ0-9_\-\'\"]+)$"
-FORMSET_FULL_REGEX = FORMSET_REGEX.format("[a-zA-ZÀ-ÿ0-9_\-\'\"]+")
+FORMSET_REGEX = "^(?P<field_name>{})-(?P<index>[0-9]+)-(?P<name>[a-zA-ZÀ-ÿ0-9_°^\-\'\"]+)$"
+FORMSET_FULL_REGEX = FORMSET_REGEX.format("[a-zA-ZÀ-ÿ0-9_°^\-\'\"]+")
 
 FORMSET_TEMPLATE_NAMEID = 'NNNNN'
 MANAGEMENT_FORMSET_STRINGS = [FORMSET_TEMPLATE_NAMEID,
